<?php
namespace XTS\Modules\Header_Builder\Elements;

use XTS\Modules\Header_Builder\Element;

/**
 * ------------------------------------------------------------------------------------------------
 *  Basic structure element - row
 * ------------------------------------------------------------------------------------------------
 */
class Row extends Element {

	public function __construct() {
		parent::__construct();

		$this->template_name = 'row';
	}

	public function map() {
		$this->args = array(
			'type'            => 'row',
			'title'           => esc_html__( 'Row', 'cheshalo' ),
			'text'            => esc_html__( 'Row', 'cheshalo' ),
			'editable'        => true,
			'container'       => false,
			'edit_on_create'  => false,
			'drag_target_for' => array(),
			'drag_source'     => '',
			'removable'       => false,
			'addable'         => false,
			'it_works'        => 'row',
			'class'           => '',
			'content'         => array(),
			'params'          => array(
				'row_columns'   => array(
					'id'      => 'row_columns',
					'title'   => esc_html__( 'Row columns', 'cheshalo' ),
					'type'    => 'selector',
					'tab'     => esc_html__( 'General', 'cheshalo' ),
					'group'   => esc_html__( 'Layout', 'cheshalo' ),
					'value'   => '3',
					'options' => array(
						'1' => array(
							'label' => 1,
							'value' => '1',
						),
						'3' => array(
							'label' => 3,
							'value' => '3',
						),
					),
				),
				'flex_layout'   => array(
					'id'          => 'flex_layout',
					'title'       => esc_html__( 'Row flex layout', 'cheshalo' ),
					'type'        => 'selector',
					'tab'         => esc_html__( 'General', 'cheshalo' ),
					'group'       => esc_html__( 'Layout', 'cheshalo' ),
					'value'       => 'flex-middle',
					'options'     => array(
						'flex-middle' => array(
							'label' => esc_html__( 'Flexible middle column', 'cheshalo' ),
							'value' => 'flex-middle',
							'image' => CHESHALO_ASSETS . '/images/header-builder/header-layout-2.jpg',
						),
						'equal-sides' => array(
							'label' => esc_html__( 'Equal right and left columns', 'cheshalo' ),
							'value' => 'equal-sides',
							'image' => CHESHALO_ASSETS . '/images/header-builder/header-layout-1.jpg',
						),
					),
					'description' => wp_kses( __( 'Determine the "flex layout" for this row. More information about both options read in our <a href="https://themefars.com/docs/cheshalo/header-builder/header-rows-flex-layouts/" target="_blank">documentation here</a>.', 'cheshalo' ), 'default' ),
					'requires'    => array(
						'row_columns' => array(
							'comparison' => 'equal',
							'value'      => '3',
						),
					),
				),
				'height'        => array(
					'id'          => 'height',
					'title'       => esc_html__( 'Row height', 'cheshalo' ),
					'type'        => 'slider',
					'tab'         => esc_html__( 'General', 'cheshalo' ),
					'group'       => esc_html__( 'Height', 'cheshalo' ),
					'from'        => 0,
					'to'          => 200,
					'value'       => 50,
					'units'       => 'px',
					'description' => esc_html__( 'Determine the header height value in pixels.', 'cheshalo' ),
				),
				'mobile_height' => array(
					'id'          => 'mobile_height',
					'title'       => esc_html__( 'Row height on mobile devices', 'cheshalo' ),
					'type'        => 'slider',
					'tab'         => esc_html__( 'General', 'cheshalo' ),
					'group'       => esc_html__( 'Height', 'cheshalo' ),
					'from'        => 0,
					'to'          => 200,
					'value'       => 40,
					'units'       => 'px',
					'description' => esc_html__( 'Determine the header height for mobile devices value in pixels.', 'cheshalo' ),
				),
				'hide_desktop'  => array(
					'id'          => 'hide_desktop',
					'title'       => esc_html__( 'Hide on desktop', 'cheshalo' ),
					'type'        => 'switcher',
					'tab'         => esc_html__( 'General', 'cheshalo' ),
					'group'       => esc_html__( 'Responsive', 'cheshalo' ),
					'value'       => false,
					'description' => esc_html__( 'Disable this row for desktop devices.', 'cheshalo' ),
					'extra_class' => 'xts-col-6',
				),
				'hide_mobile'   => array(
					'id'          => 'hide_mobile',
					'title'       => esc_html__( 'Hide on mobile', 'cheshalo' ),
					'type'        => 'switcher',
					'tab'         => esc_html__( 'General', 'cheshalo' ),
					'group'       => esc_html__( 'Responsive', 'cheshalo' ),
					'value'       => false,
					'description' => esc_html__( 'Disable this row for mobile devices.', 'cheshalo' ),
					'extra_class' => 'xts-col-6',
				),
				'sticky'        => array(
					'id'          => 'sticky',
					'title'       => esc_html__( 'Make it sticky', 'cheshalo' ),
					'hint'        => '<video src="' . CHESHALO_TOOLTIP_URL . 'hb_row_sticky.mp4" autoplay loop muted></video>',
					'type'        => 'switcher',
					'tab'         => esc_html__( 'General', 'cheshalo' ),
					'group'       => esc_html__( 'Sticky', 'cheshalo' ),
					'value'       => false,
					'description' => esc_html__( 'The following option will not work if "Sticky header clone" is enabled in header settings.', 'cheshalo' ),
				),
				'sticky_height' => array(
					'id'          => 'sticky_height',
					'title'       => esc_html__( 'Row height on sticky header', 'cheshalo' ),
					'type'        => 'slider',
					'tab'         => esc_html__( 'General', 'cheshalo' ),
					'group'       => esc_html__( 'Sticky', 'cheshalo' ),
					'from'        => 0,
					'to'          => 200,
					'value'       => 60,
					'units'       => 'px',
					'description' => esc_html__( 'Determine the header height for sticky header value in pixels.', 'cheshalo' ),
					'requires'    => array(
						'sticky' => array(
							'comparison' => 'equal',
							'value'      => true,
						),
					),
				),
				'color_scheme'  => array(
					'id'          => 'color_scheme',
					'title'       => esc_html__( 'Text color scheme', 'cheshalo' ),
					'type'        => 'selector',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Colors', 'cheshalo' ),
					'value'       => 'dark',
					'options'     => array(
						'dark'  => array(
							'value' => 'dark',
							'label' => esc_html__( 'Dark', 'cheshalo' ),
						),
						'light' => array(
							'value' => 'light',
							'label' => esc_html__( 'Light', 'cheshalo' ),
						),
					),
					'description' => esc_html__( 'Select different text color scheme depending on your background.', 'cheshalo' ),
				),
				'background'    => array(
					'id'          => 'background',
					'group'       => esc_html__( 'Colors', 'cheshalo' ),
					'type'        => 'bg',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'backdrop'    => true,
					'value'       => '',
					'description' => '',
				),
				'border'        => array(
					'id'              => 'border',
					'group'           => esc_html__( 'Border bottom', 'cheshalo' ),
					'type'            => 'border',
					'sides'           => array( 'bottom' ),
					'tab'             => esc_html__( 'Style', 'cheshalo' ),
					'colorpicker_top' => true,
					'container'       => true,
					'value'           => '',
					'description'     => esc_html__( 'Set border bottom for this header row.', 'cheshalo' ),
				),
				'shadow'        => array(
					'id'          => 'shadow',
					'title'       => esc_html__( 'Shadow', 'cheshalo' ),
					'type'        => 'switcher',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Shadow', 'cheshalo' ),
					'value'       => false,
					'description' => esc_html__( 'Add shadow to the header section.', 'cheshalo' ),
				),
			),
		);
	}
}
